==> haskell-lua-arbitrary-1.0.1.1-27-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-lua-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lua-arbitrary
version:              1.0.1.1
visibility:           public
id:                   lua-arbitrary-1.0.1.1-Ly09yf4MlzxH6B9d8vRU38
key:                  lua-arbitrary-1.0.1.1-Ly09yf4MlzxH6B9d8vRU38
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Arbitrary instances for Lua types.
description:
    Provides instances for QuickCheck'\''s \"Arbitrary\"
    typeclass.

category:             Foreign
abi:                  505d4b1209eac59d1898e6c6a436b36a
exposed:              True
exposed-modules:      Lua.Arbitrary
import-dirs:          /usr/lib/ghc-9.2.8/site-local/lua-arbitrary-1.0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lua-arbitrary-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lua-arbitrary
hs-libraries:         HSlua-arbitrary-1.0.1.1-Ly09yf4MlzxH6B9d8vRU38
depends:
    QuickCheck-2.14.3-JVpLupMbhPgL6XTp3rPxED base-4.16.4.0
    lua-2.3.2-BzFGgQ9DVIwCkQiWvOAVka

haddock-interfaces:
    /usr/share/doc/haskell-lua-arbitrary/html/lua-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-lua-arbitrary/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lua-arbitrary-1.0.1.1-30-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-lua-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lua-arbitrary
version:              1.0.1.1
visibility:           public
id:                   lua-arbitrary-1.0.1.1-DB97lqexuXfBCV7o2VQMng
key:                  lua-arbitrary-1.0.1.1-DB97lqexuXfBCV7o2VQMng
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Arbitrary instances for Lua types.
description:
    Provides instances for QuickCheck'\''s \"Arbitrary\"
    typeclass.

category:             Foreign
abi:                  371315aa4fb5310aa4b9d1f9262a0e41
exposed:              True
exposed-modules:      Lua.Arbitrary
import-dirs:          /usr/lib/ghc-9.2.8/site-local/lua-arbitrary-1.0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lua-arbitrary-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lua-arbitrary
hs-libraries:         HSlua-arbitrary-1.0.1.1-DB97lqexuXfBCV7o2VQMng
depends:
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X base-4.16.4.0
    lua-2.3.3-LJjSIwUOXmTId3gJRxtLsQ

haddock-interfaces:
    /usr/share/doc/haskell-lua-arbitrary/html/lua-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-lua-arbitrary/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
